@@ -3,7 +3,10 @@ import os
 import shutil
 import tempfile
 import logging
+import traceback
+from enum import Enum, auto
 
+from stringcase import titlecase, lowercase
 from video_utils import Video
 
 from .ffmpeg_converter import FFmpegConverter
@@ -12,21 +15,39 @@ from .settings import AudioSettings, VideoSettings
 log = logging.getLogger(__name__)
 
 
+class Status(Enum):
+    # Successful conversion
+    CONVERTED = auto()
+
+    # If a file is already converted with renaming
+    # (e.g. appending the output codec) and this is that converted file
+    ALREADY_PROCESSED = auto()
+
+    # Force can override already in desired format, but not if both original and converted files already exist
+    FORCE_CONVERTED = auto()
+
+    # The file is already using the target format, can be overridden with --force
+    IN_DESIRED_FORMAT = auto()
+
+    FAILED = auto()
+
+    def __str__(self):
+        return titlecase(lowercase(self.name))
+
+
 @dataclass
 class VideoProcessor:
     video: Video
     video_settings: VideoSettings
     audio_settings: AudioSettings
     container: str
+    force: bool = False
     dry_run: bool = False
     in_place: bool = False
     extra_ffmpeg_input_args: str = ""
     extra_ffmpeg_output_args: str = ""
     temp_directory: str = None
 
-    # def __post__init__(self):
-    #     self.temp_file = self._create_temp_file()
-
     def _create_temp_file(self):
         return tempfile.mkstemp(dir=self.temp_directory, suffix=f".{self.container}")[1]
 
@@ -34,18 +55,35 @@ class VideoProcessor:
         return f"Video: {self.video.full_path}, format: {self.video.codec.pretty_name}, quality: {self.video.quality}"
 
     def process(self):
-        self.temp_file = self._create_temp_file()
-        converter = FFmpegConverter(
-            source_file_path=self.video.full_path,
-            destination_file_path=self.temp_file,
-            extra_ffmpeg_input_args=self.extra_ffmpeg_input_args,
-            extra_ffmpeg_output_args=self.extra_ffmpeg_output_args,
-            video_settings=self.video_settings,
-            audio_settings=self.audio_settings,
-            dry_run=self.dry_run,
-        )
-        converter.process()
-        self._move_output_video()
+        if self.video.codec == self.video_settings.codec:
+            print(f"{self.video.name} is already in the desired format")
+            if not self.force:
+                return Status.IN_DESIRED_FORMAT
+            print(f"Forcing conversion anyway (--force is enabled)")
+
+        if self.already_processed():
+            return Status.ALREADY_PROCESSED
+
+        try:
+            self.temp_file = self._create_temp_file()
+            converter = FFmpegConverter(
+                source_file_path=self.video.full_path,
+                destination_file_path=self.temp_file,
+                extra_ffmpeg_input_args=self.extra_ffmpeg_input_args,
+                extra_ffmpeg_output_args=self.extra_ffmpeg_output_args,
+                video_settings=self.video_settings,
+                audio_settings=self.audio_settings,
+                dry_run=self.dry_run,
+            )
+            converter.process()
+            self._move_output_video()
+            return Status.CONVERTED
+        except Exception as e:
+            print(f"Failed to convert {self.video.full_path}. Exception:")
+            print(e)
+            traceback.print_exc()
+            print()
+            return Status.FAILED
 
     def already_processed(self):
         renamed_path = self.renamed_path()
@@ -73,6 +111,7 @@ class VideoProcessor:
         return f"{split_filename[0]}.{self.container}"
 
     def _move_output_video(self):
+        print(f"Moving file from temporary storage back to original folder")
         if not self.dry_run:
             shutil.move(self.temp_file, self.renamed_path())
         if self.in_place:
